@@ -546,10 +546,6 @@ struct rb_iseq_struct {
 
 #define ISEQ_BODY(iseq) ((iseq)->body)
 
-#ifndef EXTSTATIC
-#define EXTSTATIC 0
-#endif
-
 #ifndef USE_LAZY_LOAD
 #define USE_LAZY_LOAD 0
 #endif
@@ -683,11 +679,9 @@ typedef struct rb_vm_struct {
     VALUE loaded_features_realpath_map;
     struct st_table *loaded_features_index;
     struct st_table *loading_table;
-#if EXTSTATIC
     // For running the init function of statically linked
     // extensions when they are loaded
     struct st_table *static_ext_inits;
-#endif
 
     /* signal */
     struct {
